@@ -8,12 +8,12 @@ package Printer::ESCPOS;
 #
 # This file is part of Printer-ESCPOS
 #
-# This software is copyright (c) 2015 by Shantanu Bhadoria.
+# This software is copyright (c) 2016 by Shantanu Bhadoria.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.020'; # VERSION
+our $VERSION = '0.022'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -22,11 +22,6 @@ use Carp;
 use Type::Tiny;
 use aliased 'Printer::ESCPOS::Roles::Profile' => 'ESCPOSProfile';
 
-use Printer::ESCPOS::Connections::File;
-use Printer::ESCPOS::Connections::Network;
-use Printer::ESCPOS::Connections::Serial;
-use Printer::ESCPOS::Connections::USB;
-
 
 has driverType => (
     is       => 'ro',
@@ -43,6 +38,9 @@ has profile => (
 has deviceFilePath => ( is => 'ro', );
 
 
+has portName => ( is => 'ro', );
+
+
 has deviceIP => ( is => 'ro', );
 
 
@@ -91,16 +89,19 @@ sub _build__driver {
     my ($self) = @_;
 
     if ( $self->driverType eq 'File' ) {
+        Class::Load::load_class('Printer::ESCPOS::Connections::File');
         return Printer::ESCPOS::Connections::File->new(
             deviceFilePath => $self->deviceFilePath, );
     }
     elsif ( $self->driverType eq 'Network' ) {
+        Class::Load::load_class('Printer::ESCPOS::Connections::Network');
         return Printer::ESCPOS::Connections::Network->new(
             deviceIP   => $self->deviceIP,
             devicePort => $self->devicePort,
         );
     }
     elsif ( $self->driverType eq 'Serial' ) {
+        Class::Load::load_class('Printer::ESCPOS::Connections::Serial');
         return Printer::ESCPOS::Connections::Serial->new(
             deviceFilePath => $self->deviceFilePath,
             baudrate       => $self->baudrate,
@@ -108,6 +109,7 @@ sub _build__driver {
         );
     }
     elsif ( $self->driverType eq 'USB' ) {
+        Class::Load::load_class('Printer::ESCPOS::Connections::USB');
         return Printer::ESCPOS::Connections::USB->new(
             productId => $self->productId,
             vendorId  => $self->vendorId,
@@ -151,16 +153,30 @@ __END__
 
 Printer::ESCPOS - Interface for all thermal, dot-matrix and other receipt printers that support ESC-POS specification.
 
+
+
+=begin html
+
+<p>
+<img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" />
+<a href="https://travis-ci.org/shantanubhadoria/perl-Printer-ESCPOS"><img src="https://api.travis-ci.org/shantanubhadoria/perl-Printer-ESCPOS.svg?branch=build/master" alt="Travis status" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Printer-ESCPOS%200.022"><img src="https://badgedepot.code301.com/badge/cpantesters/Printer-ESCPOS/0.022" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Printer-ESCPOS-0.022"><img src="https://badgedepot.code301.com/badge/kwalitee/Printer-ESCPOS/0.022" alt="Distribution kwalitee" /></a>
+<a href="https://gratipay.com/shantanubhadoria"><img src="https://img.shields.io/gratipay/shantanubhadoria.svg" alt="Gratipay" /></a>
+</p>
+
+=end html
+
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 SYNOPSIS
 
 If you are just starting up with POS RECEIPT Printers, you must first refer to L<Printer::ESCPOS::Manual> to get started.
 
-Printer::ESCPOS provides four different types of printer connections to talk to a ESCPOS printer. 
-As of v0.012 I<driverType> B<Serial>, B<Network>, B<File> and B<USB> are all implemented in this module. B<USB> I<driverType> is not supported prior to v0.012. 
+Printer::ESCPOS provides four different types of printer connections to talk to a ESCPOS printer.
+As of v0.012 I<driverType> B<Serial>, B<Network>, B<File> and B<USB> are all implemented in this module. B<USB> I<driverType> is not supported prior to v0.012.
 
 =head2 USB Printer
 
@@ -168,7 +184,7 @@ B<USB> I<driverType> allows you to talk to your Printer using the I<vendorId> an
 
      shantanu@shantanu-G41M-ES2L:~/github$ lsusb
      . . .
-     Bus 003 Device 002: ID 1504:0006  
+     Bus 003 Device 002: ID 1504:0006
      . . .
 
 The output gives us the I<vendorId> 0x1504 and I<productId> 0x0006
@@ -201,11 +217,11 @@ For USB Printers L<Printer::ESCPOS> uses a default I<endPoint> of 0x01 and a def
      $device->printer->text("Upside Down\n");
      $device->printer->cutPaper();
  
-     $device->printer->print(); # Dispatch the above commands from module buffer to the Printer. 
+     $device->printer->print(); # Dispatch the above commands from module buffer to the Printer.
 
 =head2 Network Printer
 
-For Network Printers $port is 9100 in most cases but might differ depending on how 
+For Network Printers $port is 9100 in most cases but might differ depending on how
 you have configured your printer
 
      use Printer::ESCPOS;
@@ -218,7 +234,7 @@ you have configured your printer
          devicePort => $port,
      );
  
-     # These commands won't actually send anything to the printer but will store all the 
+     # These commands won't actually send anything to the printer but will store all the
      # merged data including control codes to module buffer.
      $device->printer->printAreaWidth( nL => 0, nH => 1);
      $device->printer->text("Print Area Width Modified\n");
@@ -235,14 +251,14 @@ you have configured your printer
      $device->printer->text("Upside Down\n");
      $device->printer->cutPaper();
  
-     $device->printer->print(); # Dispatch the above commands from module buffer to the Printer. 
+     $device->printer->print(); # Dispatch the above commands from module buffer to the Printer.
                                 # This command takes care of read text buffers for the printer.
 
 =head2 Serial Printer
 
-Use the B<Serial> I<driverType> for local printer connected on serial port(or a printer connected via 
-a physical USB port in USB to Serial mode), check syslog(Usually under E<sol>varE<sol>logE<sol>syslog) 
-for what device file was created for your printer when you connect it to your system(For 
+Use the B<Serial> I<driverType> for local printer connected on serial port(or a printer connected via
+a physical USB port in USB to Serial mode), check syslog(Usually under E<sol>varE<sol>logE<sol>syslog)
+for what device file was created for your printer when you connect it to your system(For
 plug and play printers).
 
      use Printer::ESCPOS;
@@ -268,8 +284,8 @@ plug and play printers).
 
 =head2 File(Direct to Device File) Printer
 
-A B<File> I<driverType> is similar to the B<Serial> I<driverType> in all functionality except that it 
-doesn't support the status functions for the printer. i.e. you will not be able to use 
+A B<File> I<driverType> is similar to the B<Serial> I<driverType> in all functionality except that it
+doesn't support the status functions for the printer. i.e. you will not be able to use
 printerStatus, offlineStatus, errorStatus or paperSensorStatus functions
 
      use Printer::ESCPOS;
@@ -295,8 +311,8 @@ You can use this module for all your ESC-POS Printing needs. If some of your pri
 
 =head2 driverType
 
-"Required attribute". The driver type to use for your printer. This can be B<File>, B<Network>, B<USB> or B<Serial>. 
-If you choose B<File> or B<Serial> driver, you must provide the I<deviceFilePath>, 
+"Required attribute". The driver type to use for your printer. This can be B<File>, B<Network>, B<USB> or B<Serial>.
+If you choose B<File> or B<Serial> driver, you must provide the I<deviceFilePath>,
 for B<Network> I<driverType> you must provide the I<printerIp> and I<printerPort>,
 For B<USB> I<driverType> you must provide I<vendorId> and I<productId>.
 
@@ -363,6 +379,10 @@ The above $device object will use the Printer::ESCPOS::Profile::USERCUSTOM profi
 
 File path for UNIX device file. e.g. "/dev/ttyACM0" this is a mandatory parameter if you are using B<File> or B<Serial> I<driverType>.
 
+=head2 portName
+
+Win32 serial port name
+
 =head2 deviceIP
 
 Contains the IP address of the device when its a network printer. The module creates L<IO:Socket::INET> object to connect to the printer. This can be passed in the constructor.
@@ -373,7 +393,7 @@ Contains the network port of the device when its a network printer. The module c
 
 =head2 baudrate
 
-When used as a local serial device you can set the I<baudrate> of the printer too. Default (38400) will usually work, but not always. 
+When used as a local serial device you can set the I<baudrate> of the printer too. Default (38400) will usually work, but not always.
 
 =head2 serialOverUSB
 
@@ -538,7 +558,7 @@ Shantanu Bhadoria <shantanu att cpan dott org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Shantanu Bhadoria.
+This software is copyright (c) 2016 by Shantanu Bhadoria.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
